<?php
namespace WPExtend;

if ( ! class_exists( 'WPExtend\BasicWPActions' ) ) {
    require_once realpath( dirname( __FILE__ ) . '/BasicWPActions.php' );
}

/**
 * Autoloder for WordPress Filter Hooks.
 * Instead of calling for each method an add_filter method, all class methods can be hooked automatically.
 * 
 * @author Dave A. Holyfield
 * @since 2.0.7
 * @version 2.0.8
 */
final class BasicWPFilters {

    /**
     */
    private function __construct () {
    }

    public static function GetFiltersList () {
        return self::$_filters;
    }

    public static function Debug () {
        $filters = array_unique( array_keys( self::$_filters ) );
        sort( $filters );
        foreach ( $filters as $action ) {
            $items = preg_split( "/_|-/uiU", $action );
            foreach ( $items as $key => $value ) {
                if ( $value == 'wp' ) {
                    $items[$key] = strtoupper( $value );
                } else {
                    $items[$key] = ucfirst( $value );
                }
            }
            $name = implode( '', $items );
            $name = (substr( $action, 0, 1 ) == '_') ? '_' . $name : $name;
            echo '\'' . $action . '\' => \'OnFilter' . $name . '\',' . PHP_EOL;
        }
    }

    /**
     *
     * @param array $filters            
     * @return array
     * @since 2.0.7
     */
    public static function GetFilterDefinitions ( $filters = null ) {
        static $default;
        if ( is_null( $filters ) ) {
            if ( ! is_array( $default ) ) {
                $default = array ();
                foreach ( self::$_filters as $key => $filt ) {
                    $default[$key] = array ( 
                        'method' => $filt,
                        'priority' => 10,
                        'args' => (array_key_exists( $key, self::$_filters_args )) ? self::$_filters_args[$key] : 1
                    );
                }
            }
            return $default;
        } elseif ( is_array( $filters ) && count( $filters ) > 0 ) {
            foreach ( $filters as $key => $filt ) {
                $filters[$key] = array ( 
                    'method' => $filt,
                    'priority' => 10,
                    'args' => (array_key_exists( $key, self::$_filters_args )) ? self::$_filters_args[$key] : 1
                );
            }
            return $filters;
        }
        return array ();
    }

    /**
     *
     * @param string $class            
     * @since 2.0.7
     */
    public static function GetClassFilterMethods ( $class ) {
        $filters = self::GetFiltersList();
        $statics = BasicWPActions::GetStaticMethods( $class );
        $methods = array_intersect( $filters, $statics );
        return self::GetFilterDefinitions( $methods );
    }

    public static function HookAllClassFilterMethods ( $class, $priorites = null ) {
        if ( class_exists( $class ) ) {
            $methods = self::GetClassFilterMethods( $class );
            if ( is_array( $priorites ) && count( $priorites ) > 0 ) {
                foreach ( $priorites as $id => $priority ) {
                    if ( array_key_exists( $id, $methods ) ) {
                        $methods[$id]['priority'] = $priority;
                    }
                }
            }
            foreach ( $methods as $key => $actioninfo ) {
                add_filter( $key, $class . '::' . $actioninfo['method'], $actioninfo['priority'], $actioninfo['args'] );
            }
        }
    }

    public static function GetHtmlTable () {
        $html[] = '<table width="100%" border="0" cellspacing="0" cellpadding="5">';
        $html[] = '<tr><th scope="col">Filter</th><th scope="col">Method Name</th></tr>';
        foreach ( self::$_filters as $key => $value ) {
            $html[] = '<tr><td><a href="https://developer.wordpress.org/reference/hooks/' . $key . '" target="_blank" style="text-decoration: none;">' . $key . '</a></td><td>' . $value . '</td></tr>';
        }
        $html[] = '</table>';
        return implode( PHP_EOL, $html );
    }

    public static function GetCount () {
        return count( self::$_filters );
    }

    private static $_filters_args = array ();

    /**
     * All supported filter hooks.
     *
     * @version 4.1
     * @var array
     */
    private static $_filters = array ( 
        'add_menu_classes' => 'OnFilterAddMenuClasses',
        'add_ping' => 'OnFilterAddPing',
        'add_signup_meta' => 'OnFilterAddSignupMeta',
        'additional_capabilities_display' => 'OnFilterAdditionalCapabilitiesDisplay',
        'admin_body_class' => 'OnFilterAdminBodyClass',
        'admin_comment_types_dropdown' => 'OnFilterAdminCommentTypesDropdown',
        'admin_footer_text' => 'OnFilterAdminFooterText',
        'admin_memory_limit' => 'OnFilterAdminMemoryLimit',
        'admin_post_thumbnail_html' => 'OnFilterAdminPostThumbnailHtml',
        'admin_title' => 'OnFilterAdminTitle',
        'admin_url' => 'OnFilterAdminUrl',
        'ajax_query_attachments_args' => 'OnFilterAjaxQueryAttachmentsArgs',
        'akismet_comment_nonce' => 'OnFilterAkismetCommentNonce',
        'akismet_delete_commentmeta_interval' => 'OnFilterAkismetDeleteCommentmetaInterval',
        'akismet_optimize_table' => 'OnFilterAkismetOptimizeTable',
        'akismet_show_user_comments_approved' => 'OnFilterAkismetShowUserCommentsApproved',
        'akismet_spam_count_incr' => 'OnFilterAkismetSpamCountIncr',
        'akismet_ua' => 'OnFilterAkismetUa',
        'akismet_view_arguments' => 'OnFilterAkismetViewArguments',
        'all_plugins' => 'OnFilterAllPlugins',
        'all_themes' => 'OnFilterAllThemes',
        'allow_dev_auto_core_updates' => 'OnFilterAllowDevAutoCoreUpdates',
        'allow_major_auto_core_updates' => 'OnFilterAllowMajorAutoCoreUpdates',
        'allow_minor_auto_core_updates' => 'OnFilterAllowMinorAutoCoreUpdates',
        'allow_password_reset' => 'OnFilterAllowPasswordReset',
        'allow_subdirectory_install' => 'OnFilterAllowSubdirectoryInstall',
        'allowed_http_origin' => 'OnFilterAllowedHttpOrigin',
        'allowed_http_origins' => 'OnFilterAllowedHttpOrigins',
        'allowed_redirect_hosts' => 'OnFilterAllowedRedirectHosts',
        'allowed_themes' => 'OnFilterAllowedThemes',
        'async_update_translation' => 'OnFilterAsyncUpdateTranslation',
        'atom_enclosure' => 'OnFilterAtomEnclosure',
        'attach_session_information' => 'OnFilterAttachSessionInformation',
        'attachment_fields_to_edit' => 'OnFilterAttachmentFieldsToEdit',
        'attachment_fields_to_save' => 'OnFilterAttachmentFieldsToSave',
        'attachment_icon' => 'OnFilterAttachmentIcon',
        'attachment_innerHTML' => 'OnFilterAttachmentInnerHTML',
        'attachment_link' => 'OnFilterAttachmentLink',
        'attachment_max_dims' => 'OnFilterAttachmentMaxDims',
        'attachment_thumbnail_args' => 'OnFilterAttachmentThumbnailArgs',
        'attribute_escape' => 'OnFilterAttributeEscape',
        'audio_submitbox_misc_sections' => 'OnFilterAudioSubmitboxMiscSections',
        'auth_cookie' => 'OnFilterAuthCookie',
        'auth_cookie_expiration' => 'OnFilterAuthCookieExpiration',
        'auth_redirect_scheme' => 'OnFilterAuthRedirectScheme',
        'authenticate' => 'OnFilterAuthenticate',
        'author_email' => 'OnFilterAuthorEmail',
        'author_feed_link' => 'OnFilterAuthorFeedLink',
        'author_link' => 'OnFilterAuthorLink',
        'author_rewrite_rules' => 'OnFilterAuthorRewriteRules',
        'auto_core_update_email' => 'OnFilterAutoCoreUpdateEmail',
        'auto_core_update_send_email' => 'OnFilterAutoCoreUpdateSendEmail',
        'autocomplete_users_for_site_admins' => 'OnFilterAutocompleteUsersForSiteAdmins',
        'automatic_updater_disabled' => 'OnFilterAutomaticUpdaterDisabled',
        'automatic_updates_debug_email' => 'OnFilterAutomaticUpdatesDebugEmail',
        'automatic_updates_is_vcs_checkout' => 'OnFilterAutomaticUpdatesIsVcsCheckout',
        'automatic_updates_send_debug_email' => 'OnFilterAutomaticUpdatesSendDebugEmail',
        'avatar_defaults' => 'OnFilterAvatarDefaults',
        'block_local_requests' => 'OnFilterBlockLocalRequests',
        'blog_details' => 'OnFilterBlogDetails',
        'blog_redirect_404' => 'OnFilterBlogRedirect404',
        'bloginfo' => 'OnFilterBloginfo',
        'bloginfo_rss' => 'OnFilterBloginfoRss',
        'bloginfo_url' => 'OnFilterBloginfoUrl',
        'body_class' => 'OnFilterBodyClass',
        'browse-happy-notice' => 'OnFilterBrowseHappyNotice',
        'bulk_post_updated_messages' => 'OnFilterBulkPostUpdatedMessages',
        'can_edit_network' => 'OnFilterCanEditNetwork',
        'cancel_comment_reply_link' => 'OnFilterCancelCommentReplyLink',
        'category_description' => 'OnFilterCategoryDescription',
        'category_feed_link' => 'OnFilterCategoryFeedLink',
        'category_link' => 'OnFilterCategoryLink',
        'check_is_user_spammed' => 'OnFilterCheckIsUserSpammed',
        'check_password' => 'OnFilterCheckPassword',
        'clean_url' => 'OnFilterCleanUrl',
        'close_comments_for_post_types' => 'OnFilterCloseCommentsForPostTypes',
        'comment_author' => 'OnFilterCommentAuthor',
        'comment_author_rss' => 'OnFilterCommentAuthorRss',
        'comment_class' => 'OnFilterCommentClass',
        'comment_cookie_lifetime' => 'OnFilterCommentCookieLifetime',
        'comment_edit_pre' => 'OnFilterCommentEditPre',
        'comment_edit_redirect' => 'OnFilterCommentEditRedirect',
        'comment_email' => 'OnFilterCommentEmail',
        'comment_excerpt' => 'OnFilterCommentExcerpt',
        'comment_feed_groupby' => 'OnFilterCommentFeedGroupby',
        'comment_feed_join' => 'OnFilterCommentFeedJoin',
        'comment_feed_limits' => 'OnFilterCommentFeedLimits',
        'comment_feed_orderby' => 'OnFilterCommentFeedOrderby',
        'comment_feed_where' => 'OnFilterCommentFeedWhere',
        'comment_flood_filter' => 'OnFilterCommentFloodFilter',
        'comment_form_default_fields' => 'OnFilterCommentFormDefaultFields',
        'comment_form_defaults' => 'OnFilterCommentFormDefaults',
        'comment_form_field_comment' => 'OnFilterCommentFormFieldComment',
        'comment_form_logged_in' => 'OnFilterCommentFormLoggedIn',
        'comment_id_fields' => 'OnFilterCommentIdFields',
        'comment_link' => 'OnFilterCommentLink',
        'comment_max_links_url' => 'OnFilterCommentMaxLinksUrl',
        'comment_moderation_headers' => 'OnFilterCommentModerationHeaders',
        'comment_moderation_recipients' => 'OnFilterCommentModerationRecipients',
        'comment_moderation_subject' => 'OnFilterCommentModerationSubject',
        'comment_moderation_text' => 'OnFilterCommentModerationText',
        'comment_notification_headers' => 'OnFilterCommentNotificationHeaders',
        'comment_notification_notify_author' => 'OnFilterCommentNotificationNotifyAuthor',
        'comment_notification_recipients' => 'OnFilterCommentNotificationRecipients',
        'comment_notification_subject' => 'OnFilterCommentNotificationSubject',
        'comment_notification_text' => 'OnFilterCommentNotificationText',
        'comment_post_redirect' => 'OnFilterCommentPostRedirect',
        'comment_reply_link' => 'OnFilterCommentReplyLink',
        'comment_reply_link_args' => 'OnFilterCommentReplyLinkArgs',
        'comment_row_actions' => 'OnFilterCommentRowActions',
        'comment_save_pre' => 'OnFilterCommentSavePre',
        'comment_status_links' => 'OnFilterCommentStatusLinks',
        'comment_text' => 'OnFilterCommentText',
        'comment_text_rss' => 'OnFilterCommentTextRss',
        'comment_url' => 'OnFilterCommentUrl',
        'comments_array' => 'OnFilterCommentsArray',
        'comments_clauses' => 'OnFilterCommentsClauses',
        'comments_link_feed' => 'OnFilterCommentsLinkFeed',
        'comments_number' => 'OnFilterCommentsNumber',
        'comments_open' => 'OnFilterCommentsOpen',
        'comments_per_page' => 'OnFilterCommentsPerPage',
        'comments_popup_link_attributes' => 'OnFilterCommentsPopupLinkAttributes',
        'comments_rewrite_rules' => 'OnFilterCommentsRewriteRules',
        'comments_template' => 'OnFilterCommentsTemplate',
        'content_url' => 'OnFilterContentUrl',
        'contextual_help' => 'OnFilterContextualHelp',
        'contextual_help_list' => 'OnFilterContextualHelpList',
        'core_version_check_locale' => 'OnFilterCoreVersionCheckLocale',
        'cron_request' => 'OnFilterCronRequest',
        'cron_schedules' => 'OnFilterCronSchedules',
        'current_screen' => 'OnFilterCurrentScreen',
        'custom_menu_order' => 'OnFilterCustomMenuOrder',
        'customize_allowed_urls' => 'OnFilterCustomizeAllowedUrls',
        'customize_control_active' => 'OnFilterCustomizeControlActive',
        'customize_panel_active' => 'OnFilterCustomizePanelActive',
        'customize_section_active' => 'OnFilterCustomizeSectionActive',
        'customizer_widgets_section_args' => 'OnFilterCustomizerWidgetsSectionArgs',
        'dashboard_glance_items' => 'OnFilterDashboardGlanceItems',
        'dashboard_primary_feed' => 'OnFilterDashboardPrimaryFeed',
        'dashboard_primary_link' => 'OnFilterDashboardPrimaryLink',
        'dashboard_primary_title' => 'OnFilterDashboardPrimaryTitle',
        'dashboard_secondary_feed' => 'OnFilterDashboardSecondaryFeed',
        'dashboard_secondary_link' => 'OnFilterDashboardSecondaryLink',
        'dashboard_secondary_title' => 'OnFilterDashboardSecondaryTitle',
        'date_formats' => 'OnFilterDateFormats',
        'date_i18n' => 'OnFilterDateI18n',
        'date_query_valid_columns' => 'OnFilterDateQueryValidColumns',
        'date_rewrite_rules' => 'OnFilterDateRewriteRules',
        'day_link' => 'OnFilterDayLink',
        'dbdelta_create_queries' => 'OnFilterDbdeltaCreateQueries',
        'dbdelta_insert_queries' => 'OnFilterDbdeltaInsertQueries',
        'dbdelta_queries' => 'OnFilterDbdeltaQueries',
        'default_avatar_select' => 'OnFilterDefaultAvatarSelect',
        'default_content' => 'OnFilterDefaultContent',
        'default_contextual_help' => 'OnFilterDefaultContextualHelp',
        'default_excerpt' => 'OnFilterDefaultExcerpt',
        'default_feed' => 'OnFilterDefaultFeed',
        'default_hidden_meta_boxes' => 'OnFilterDefaultHiddenMetaBoxes',
        'default_page_template_title' => 'OnFilterDefaultPageTemplateTitle',
        'default_title' => 'OnFilterDefaultTitle',
        'delete_site_email_content' => 'OnFilterDeleteSiteEmailContent',
        'deprecated_argument_trigger_error' => 'OnFilterDeprecatedArgumentTriggerError',
        'deprecated_file_trigger_error' => 'OnFilterDeprecatedFileTriggerError',
        'deprecated_function_trigger_error' => 'OnFilterDeprecatedFunctionTriggerError',
        'determine_current_user' => 'OnFilterDetermineCurrentUser',
        'disable_captions' => 'OnFilterDisableCaptions',
        'display_media_states' => 'OnFilterDisplayMediaStates',
        'display_post_states' => 'OnFilterDisplayPostStates',
        'do_mu_upgrade' => 'OnFilterDoMuUpgrade',
        'do_parse_request' => 'OnFilterDoParseRequest',
        'documentation_ignore_functions' => 'OnFilterDocumentationIgnoreFunctions',
        'doing_it_wrong_trigger_error' => 'OnFilterDoingItWrongTriggerError',
        'domain_exists' => 'OnFilterDomainExists',
        'dynamic_sidebar_has_widgets' => 'OnFilterDynamicSidebarHasWidgets',
        'dynamic_sidebar_params' => 'OnFilterDynamicSidebarParams',
        'edit_bookmark_link' => 'OnFilterEditBookmarkLink',
        'edit_categories_per_page' => 'OnFilterEditCategoriesPerPage',
        'edit_comment_link' => 'OnFilterEditCommentLink',
        'edit_post_link' => 'OnFilterEditPostLink',
        'edit_posts_per_page' => 'OnFilterEditPostsPerPage',
        'edit_profile_url' => 'OnFilterEditProfileUrl',
        'edit_tag_link' => 'OnFilterEditTagLink',
        'edit_tags_per_page' => 'OnFilterEditTagsPerPage',
        'edit_term_link' => 'OnFilterEditTermLink',
        'editable_extensions' => 'OnFilterEditableExtensions',
        'editable_roles' => 'OnFilterEditableRoles',
        'editable_slug' => 'OnFilterEditableSlug',
        'editor_max_image_size' => 'OnFilterEditorMaxImageSize',
        'embed_cache_oembed_types' => 'OnFilterEmbedCacheOembedTypes',
        'embed_defaults' => 'OnFilterEmbedDefaults',
        'embed_googlevideo' => 'OnFilterEmbedGooglevideo',
        'embed_handler_html' => 'OnFilterEmbedHandlerHtml',
        'embed_maybe_make_link' => 'OnFilterEmbedMaybeMakeLink',
        'embed_oembed_discover' => 'OnFilterEmbedOembedDiscover',
        'embed_oembed_html' => 'OnFilterEmbedOembedHtml',
        'enable_edit_any_user_configuration' => 'OnFilterEnableEditAnyUserConfiguration',
        'enable_live_network_counts' => 'OnFilterEnableLiveNetworkCounts',
        'enable_post_by_email_configuration' => 'OnFilterEnablePostByEmailConfiguration',
        'enable_update_services_configuration' => 'OnFilterEnableUpdateServicesConfiguration',
        'enter_title_here' => 'OnFilterEnterTitleHere',
        'esc_html' => 'OnFilterEscHtml',
        'esc_textarea' => 'OnFilterEscTextarea',
        'excerpt_length' => 'OnFilterExcerptLength',
        'excerpt_more' => 'OnFilterExcerptMore',
        'exit_on_http_head' => 'OnFilterExitOnHttpHead',
        'export_args' => 'OnFilterExportArgs',
        'ext2type' => 'OnFilterExt2type',
        'extra_theme_headers' => 'OnFilterExtraThemeHeaders',
        'feed_content_type' => 'OnFilterFeedContentType',
        'feed_link' => 'OnFilterFeedLink',
        'file_is_displayable_image' => 'OnFilterFileIsDisplayableImage',
        'filesystem_method' => 'OnFilterFilesystemMethod',
        'filesystem_method_file' => 'OnFilterFilesystemMethodFile',
        'flush_rewrite_rules_hard' => 'OnFilterFlushRewriteRulesHard',
        'force_filtered_html_on_import' => 'OnFilterForceFilteredHtmlOnImport',
        'format_to_edit' => 'OnFilterFormatToEdit',
        'found_posts' => 'OnFilterFoundPosts',
        'found_posts_query' => 'OnFilterFoundPostsQuery',
        'found_users_query' => 'OnFilterFoundUsersQuery',
        'fs_ftp_connection_types' => 'OnFilterFsFtpConnectionTypes',
        'gallery_style' => 'OnFilterGalleryStyle',
        'get_ancestors' => 'OnFilterGetAncestors',
        'get_archives_link' => 'OnFilterGetArchivesLink',
        'get_attached_file' => 'OnFilterGetAttachedFile',
        'get_attached_media' => 'OnFilterGetAttachedMedia',
        'get_attached_media_args' => 'OnFilterGetAttachedMediaArgs',
        'get_avatar' => 'OnFilterGetAvatar',
        'get_avatar_comment_types' => 'OnFilterGetAvatarCommentTypes',
        'get_bloginfo_rss' => 'OnFilterGetBloginfoRss',
        'get_blogs_of_user' => 'OnFilterGetBlogsOfUser',
        'get_bookmarks' => 'OnFilterGetBookmarks',
        'get_calendar' => 'OnFilterGetCalendar',
        'get_categories_taxonomy' => 'OnFilterGetCategoriesTaxonomy',
        'get_comment' => 'OnFilterGetComment',
        'get_comment_author' => 'OnFilterGetCommentAuthor',
        'get_comment_author_email' => 'OnFilterGetCommentAuthorEmail',
        'get_comment_author_IP' => 'OnFilterGetCommentAuthorIP',
        'get_comment_author_link' => 'OnFilterGetCommentAuthorLink',
        'get_comment_author_url' => 'OnFilterGetCommentAuthorUrl',
        'get_comment_author_url_link' => 'OnFilterGetCommentAuthorUrlLink',
        'get_comment_date' => 'OnFilterGetCommentDate',
        'get_comment_excerpt' => 'OnFilterGetCommentExcerpt',
        'get_comment_ID' => 'OnFilterGetCommentID',
        'get_comment_link' => 'OnFilterGetCommentLink',
        'get_comment_text' => 'OnFilterGetCommentText',
        'get_comment_time' => 'OnFilterGetCommentTime',
        'get_comment_type' => 'OnFilterGetCommentType',
        'get_comments_link' => 'OnFilterGetCommentsLink',
        'get_comments_number' => 'OnFilterGetCommentsNumber',
        'get_comments_pagenum_link' => 'OnFilterGetCommentsPagenumLink',
        'get_date_sql' => 'OnFilterGetDateSql',
        'get_delete_post_link' => 'OnFilterGetDeletePostLink',
        'get_edit_bookmark_link' => 'OnFilterGetEditBookmarkLink',
        'get_edit_comment_link' => 'OnFilterGetEditCommentLink',
        'get_edit_post_link' => 'OnFilterGetEditPostLink',
        'get_edit_tag_link' => 'OnFilterGetEditTagLink',
        'get_edit_term_link' => 'OnFilterGetEditTermLink',
        'get_edit_user_link' => 'OnFilterGetEditUserLink',
        'get_editable_authors' => 'OnFilterGetEditableAuthors',
        'get_enclosed' => 'OnFilterGetEnclosed',
        'get_image_tag' => 'OnFilterGetImageTag',
        'get_image_tag_class' => 'OnFilterGetImageTagClass',
        'get_lastpostdate' => 'OnFilterGetLastpostdate',
        'get_lastpostmodified' => 'OnFilterGetLastpostmodified',
        'get_media_item_args' => 'OnFilterGetMediaItemArgs',
        'get_meta_sql' => 'OnFilterGetMetaSql',
        'get_others_drafts' => 'OnFilterGetOthersDrafts',
        'get_pagenum_link' => 'OnFilterGetPagenumLink',
        'get_pages' => 'OnFilterGetPages',
        'get_post_galleries' => 'OnFilterGetPostGalleries',
        'get_post_gallery' => 'OnFilterGetPostGallery',
        'get_post_modified_time' => 'OnFilterGetPostModifiedTime',
        'get_post_time' => 'OnFilterGetPostTime',
        'get_pung' => 'OnFilterGetPung',
        'get_sample_permalink_html' => 'OnFilterGetSamplePermalinkHtml',
        'get_search_form' => 'OnFilterGetSearchForm',
        'get_search_query' => 'OnFilterGetSearchQuery',
        'get_shortlink' => 'OnFilterGetShortlink',
        'get_space_allowed' => 'OnFilterGetSpaceAllowed',
        'get_tags' => 'OnFilterGetTags',
        'get_term' => 'OnFilterGetTerm',
        'get_terms' => 'OnFilterGetTerms',
        'get_terms_args' => 'OnFilterGetTermsArgs',
        'get_terms_fields' => 'OnFilterGetTermsFields',
        'get_terms_orderby' => 'OnFilterGetTermsOrderby',
        'get_the_archive_description' => 'OnFilterGetTheArchiveDescription',
        'get_the_archive_title' => 'OnFilterGetTheArchiveTitle',
        'get_the_categories' => 'OnFilterGetTheCategories',
        'get_the_date' => 'OnFilterGetTheDate',
        'get_the_excerpt' => 'OnFilterGetTheExcerpt',
        'get_the_guid' => 'OnFilterGetTheGuid',
        'get_the_modified_date' => 'OnFilterGetTheModifiedDate',
        'get_the_modified_time' => 'OnFilterGetTheModifiedTime',
        'get_the_tags' => 'OnFilterGetTheTags',
        'get_the_terms' => 'OnFilterGetTheTerms',
        'get_the_time' => 'OnFilterGetTheTime',
        'get_to_ping' => 'OnFilterGetToPing',
        'get_usernumposts' => 'OnFilterGetUsernumposts',
        'get_users_drafts' => 'OnFilterGetUsersDrafts',
        'get_wp_title_rss' => 'OnFilterGetWPTitleRss',
        'getarchives_join' => 'OnFilterGetarchivesJoin',
        'getarchives_where' => 'OnFilterGetarchivesWhere',
        'getimagesize_mimes_to_exts' => 'OnFilterGetimagesizeMimesToExts',
        'gettext' => 'OnFilterGettext',
        'gettext_with_context' => 'OnFilterGettextWithContext',
        'global_terms_enabled' => 'OnFilterGlobalTermsEnabled',
        'got_rewrite' => 'OnFilterGotRewrite',
        'got_url_rewrite' => 'OnFilterGotUrlRewrite',
        'graceful_fail' => 'OnFilterGracefulFail',
        'graceful_fail_template' => 'OnFilterGracefulFailTemplate',
        'heartbeat_nopriv_received' => 'OnFilterHeartbeatNoprivReceived',
        'heartbeat_nopriv_send' => 'OnFilterHeartbeatNoprivSend',
        'heartbeat_received' => 'OnFilterHeartbeatReceived',
        'heartbeat_send' => 'OnFilterHeartbeatSend',
        'heartbeat_settings' => 'OnFilterHeartbeatSettings',
        'hidden_meta_boxes' => 'OnFilterHiddenMetaBoxes',
        'home_url' => 'OnFilterHomeUrl',
        'htmledit_pre' => 'OnFilterHtmleditPre',
        'http_api_transports' => 'OnFilterHttpApiTransports',
        'http_headers_useragent' => 'OnFilterHttpHeadersUseragent',
        'http_origin' => 'OnFilterHttpOrigin',
        'http_request_args' => 'OnFilterHttpRequestArgs',
        'http_request_host_is_external' => 'OnFilterHttpRequestHostIsExternal',
        'http_request_redirection_count' => 'OnFilterHttpRequestRedirectionCount',
        'http_request_reject_unsafe_urls' => 'OnFilterHttpRequestRejectUnsafeUrls',
        'http_request_timeout' => 'OnFilterHttpRequestTimeout',
        'http_request_version' => 'OnFilterHttpRequestVersion',
        'http_response' => 'OnFilterHttpResponse',
        'https_local_ssl_verify' => 'OnFilterHttpsLocalSslVerify',
        'https_ssl_verify' => 'OnFilterHttpsSslVerify',
        'human_time_diff' => 'OnFilterHumanTimeDiff',
        'icon_dir' => 'OnFilterIconDir',
        'icon_dir_uri' => 'OnFilterIconDirUri',
        'icon_dirs' => 'OnFilterIconDirs',
        'iis7_supports_permalinks' => 'OnFilterIis7SupportsPermalinks',
        'iis7_url_rewrite_rules' => 'OnFilterIis7UrlRewriteRules',
        'image_add_caption_shortcode' => 'OnFilterImageAddCaptionShortcode',
        'image_add_caption_text' => 'OnFilterImageAddCaptionText',
        'image_downsize' => 'OnFilterImageDownsize',
        'image_edit_before_change' => 'OnFilterImageEditBeforeChange',
        'image_editor_default_mime_type' => 'OnFilterImageEditorDefaultMimeType',
        'image_editor_save_pre' => 'OnFilterImageEditorSavePre',
        'image_make_intermediate_size' => 'OnFilterImageMakeIntermediateSize',
        'image_memory_limit' => 'OnFilterImageMemoryLimit',
        'image_resize_dimensions' => 'OnFilterImageResizeDimensions',
        'image_save_pre' => 'OnFilterImageSavePre',
        'image_send_to_editor' => 'OnFilterImageSendToEditor',
        'image_send_to_editor_url' => 'OnFilterImageSendToEditorUrl',
        'image_size_names_choose' => 'OnFilterImageSizeNamesChoose',
        'img_caption_shortcode' => 'OnFilterImgCaptionShortcode',
        'img_caption_shortcode_width' => 'OnFilterImgCaptionShortcodeWidth',
        'import_upload_size_limit' => 'OnFilterImportUploadSizeLimit',
        'includes_url' => 'OnFilterIncludesUrl',
        'incompatible_sql_modes' => 'OnFilterIncompatibleSqlModes',
        'index_rel_link' => 'OnFilterIndexRelLink',
        'install_plugin_complete_actions' => 'OnFilterInstallPluginCompleteActions',
        'install_plugins_nonmenu_tabs' => 'OnFilterInstallPluginsNonmenuTabs',
        'install_plugins_tabs' => 'OnFilterInstallPluginsTabs',
        'install_theme_complete_actions' => 'OnFilterInstallThemeCompleteActions',
        'install_themes_nonmenu_tabs' => 'OnFilterInstallThemesNonmenuTabs',
        'install_themes_tabs' => 'OnFilterInstallThemesTabs',
        'intermediate_image_sizes' => 'OnFilterIntermediateImageSizes',
        'intermediate_image_sizes_advanced' => 'OnFilterIntermediateImageSizesAdvanced',
        'is_active_sidebar' => 'OnFilterIsActiveSidebar',
        'is_email' => 'OnFilterIsEmail',
        'is_email_address_unsafe' => 'OnFilterIsEmailAddressUnsafe',
        'is_multi_author' => 'OnFilterIsMultiAuthor',
        'is_protected_meta' => 'OnFilterIsProtectedMeta',
        'is_wide_widget_in_customizer' => 'OnFilterIsWideWidgetInCustomizer',
        'jpeg_quality' => 'OnFilterJpegQuality',
        'js_escape' => 'OnFilterJsEscape',
        'kses_allowed_protocols' => 'OnFilterKsesAllowedProtocols',
        'lang_codes' => 'OnFilterLangCodes',
        'language_attributes' => 'OnFilterLanguageAttributes',
        'link_category' => 'OnFilterLinkCategory',
        'link_title' => 'OnFilterLinkTitle',
        'list_cats' => 'OnFilterListCats',
        'list_pages' => 'OnFilterListPages',
        'list_terms_exclusions' => 'OnFilterListTermsExclusions',
        'load_default_embeds' => 'OnFilterLoadDefaultEmbeds',
        'load_default_widgets' => 'OnFilterLoadDefaultWidgets',
        'load_image_to_edit' => 'OnFilterLoadImageToEdit',
        'load_image_to_edit_attachmenturl' => 'OnFilterLoadImageToEditAttachmenturl',
        'load_image_to_edit_filesystempath' => 'OnFilterLoadImageToEditFilesystempath',
        'load_image_to_edit_path' => 'OnFilterLoadImageToEditPath',
        'load_textdomain_mofile' => 'OnFilterLoadTextdomainMofile',
        'locale' => 'OnFilterLocale',
        'locale_stylesheet_uri' => 'OnFilterLocaleStylesheetUri',
        'login_body_class' => 'OnFilterLoginBodyClass',
        'login_errors' => 'OnFilterLoginErrors',
        'login_form_bottom' => 'OnFilterLoginFormBottom',
        'login_form_defaults' => 'OnFilterLoginFormDefaults',
        'login_form_middle' => 'OnFilterLoginFormMiddle',
        'login_form_top' => 'OnFilterLoginFormTop',
        'login_headertitle' => 'OnFilterLoginHeadertitle',
        'login_headerurl' => 'OnFilterLoginHeaderurl',
        'login_message' => 'OnFilterLoginMessage',
        'login_messages' => 'OnFilterLoginMessages',
        'login_redirect' => 'OnFilterLoginRedirect',
        'login_url' => 'OnFilterLoginUrl',
        'loginout' => 'OnFilterLoginout',
        'logout_url' => 'OnFilterLogoutUrl',
        'lostpassword_redirect' => 'OnFilterLostpasswordRedirect',
        'lostpassword_url' => 'OnFilterLostpasswordUrl',
        'manage_media_columns' => 'OnFilterManageMediaColumns',
        'manage_pages_columns' => 'OnFilterManagePagesColumns',
        'manage_posts_columns' => 'OnFilterManagePostsColumns',
        'manage_sites_action_links' => 'OnFilterManageSitesActionLinks',
        'manage_taxonomies_for_attachment_columns' => 'OnFilterManageTaxonomiesForAttachmentColumns',
        'manage_users_custom_column' => 'OnFilterManageUsersCustomColumn',
        'map_meta_cap' => 'OnFilterMapMetaCap',
        'mce_buttons' => 'OnFilterMceButtons',
        'mce_buttons_2' => 'OnFilterMceButtons2',
        'mce_buttons_3' => 'OnFilterMceButtons3',
        'mce_buttons_4' => 'OnFilterMceButtons4',
        'mce_css' => 'OnFilterMceCss',
        'mce_external_languages' => 'OnFilterMceExternalLanguages',
        'mce_external_plugins' => 'OnFilterMceExternalPlugins',
        'media_buttons_context' => 'OnFilterMediaButtonsContext',
        'media_meta' => 'OnFilterMediaMeta',
        'media_row_actions' => 'OnFilterMediaRowActions',
        'media_send_to_editor' => 'OnFilterMediaSendToEditor',
        'media_submitbox_misc_sections' => 'OnFilterMediaSubmitboxMiscSections',
        'media_upload_default_tab' => 'OnFilterMediaUploadDefaultTab',
        'media_upload_default_type' => 'OnFilterMediaUploadDefaultType',
        'media_upload_form_url' => 'OnFilterMediaUploadFormUrl',
        'media_upload_mime_type_links' => 'OnFilterMediaUploadMimeTypeLinks',
        'media_upload_tabs' => 'OnFilterMediaUploadTabs',
        'media_view_settings' => 'OnFilterMediaViewSettings',
        'media_view_strings' => 'OnFilterMediaViewStrings',
        'menu_order' => 'OnFilterMenuOrder',
        'meta_query_find_compatible_table_alias' => 'OnFilterMetaQueryFindCompatibleTableAlias',
        'mime_types' => 'OnFilterMimeTypes',
        'mod_rewrite_rules' => 'OnFilterModRewriteRules',
        'month_link' => 'OnFilterMonthLink',
        'months_dropdown_results' => 'OnFilterMonthsDropdownResults',
        'ms_site_check' => 'OnFilterMsSiteCheck',
        'ms_user_list_site_actions' => 'OnFilterMsUserListSiteActions',
        'ms_user_row_actions' => 'OnFilterMsUserRowActions',
        'mu_dropdown_languages' => 'OnFilterMuDropdownLanguages',
        'mu_menu_items' => 'OnFilterMuMenuItems',
        'myblogs_blog_actions' => 'OnFilterMyblogsBlogActions',
        'myblogs_options' => 'OnFilterMyblogsOptions',
        'nav_menu_attr_title' => 'OnFilterNavMenuAttrTitle',
        'nav_menu_css_class' => 'OnFilterNavMenuCssClass',
        'nav_menu_description' => 'OnFilterNavMenuDescription',
        'nav_menu_item_id' => 'OnFilterNavMenuItemId',
        'nav_menu_link_attributes' => 'OnFilterNavMenuLinkAttributes',
        'nav_menu_meta_box_object' => 'OnFilterNavMenuMetaBoxObject',
        'network_admin_url' => 'OnFilterNetworkAdminUrl',
        'network_by_path_segments_count' => 'OnFilterNetworkByPathSegmentsCount',
        'network_home_url' => 'OnFilterNetworkHomeUrl',
        'network_site_url' => 'OnFilterNetworkSiteUrl',
        'new_admin_email_content' => 'OnFilterNewAdminEmailContent',
        'new_user_email_content' => 'OnFilterNewUserEmailContent',
        'newblog_notify_siteadmin' => 'OnFilterNewblogNotifySiteadmin',
        'newblogname' => 'OnFilterNewblogname',
        'newuser_notify_siteadmin' => 'OnFilterNewuserNotifySiteadmin',
        'next_comments_link_attributes' => 'OnFilterNextCommentsLinkAttributes',
        'next_posts_link_attributes' => 'OnFilterNextPostsLinkAttributes',
        'ngettext' => 'OnFilterNgettext',
        'ngettext_with_context' => 'OnFilterNgettextWithContext',
        'no_texturize_shortcodes' => 'OnFilterNoTexturizeShortcodes',
        'no_texturize_tags' => 'OnFilterNoTexturizeTags',
        'nocache_headers' => 'OnFilterNocacheHeaders',
        'nonce_life' => 'OnFilterNonceLife',
        'nonce_user_logged_out' => 'OnFilterNonceUserLoggedOut',
        'number_format_i18n' => 'OnFilterNumberFormatI18n',
        'oembed_dataparse' => 'OnFilterOembedDataparse',
        'oembed_fetch_url' => 'OnFilterOembedFetchUrl',
        'oembed_linktypes' => 'OnFilterOembedLinktypes',
        'oembed_providers' => 'OnFilterOembedProviders',
        'oembed_remote_get_args' => 'OnFilterOembedRemoteGetArgs',
        'oembed_result' => 'OnFilterOembedResult',
        'oembed_ttl' => 'OnFilterOembedTtl',
        'option_enable_xmlrpc' => 'OnFilterOptionEnableXmlrpc',
        'override_load_textdomain' => 'OnFilterOverrideLoadTextdomain',
        'override_post_lock' => 'OnFilterOverridePostLock',
        'override_unload_textdomain' => 'OnFilterOverrideUnloadTextdomain',
        'page_attributes_dropdown_pages_args' => 'OnFilterPageAttributesDropdownPagesArgs',
        'page_css_class' => 'OnFilterPageCssClass',
        'page_link' => 'OnFilterPageLink',
        'page_rewrite_rules' => 'OnFilterPageRewriteRules',
        'page_row_actions' => 'OnFilterPageRowActions',
        'paginate_links' => 'OnFilterPaginateLinks',
        'parent_file' => 'OnFilterParentFile',
        'parent_post_rel_link' => 'OnFilterParentPostRelLink',
        'password_hint' => 'OnFilterPasswordHint',
        'password_reset_key_expired' => 'OnFilterPasswordResetKeyExpired',
        'phone_content' => 'OnFilterPhoneContent',
        'pingback_ping_source_uri' => 'OnFilterPingbackPingSourceUri',
        'pingback_useragent' => 'OnFilterPingbackUseragent',
        'pings_open' => 'OnFilterPingsOpen',
        'plugin_install_action_links' => 'OnFilterPluginInstallActionLinks',
        'plugin_locale' => 'OnFilterPluginLocale',
        'plugin_row_meta' => 'OnFilterPluginRowMeta',
        'plugins_api' => 'OnFilterPluginsApi',
        'plugins_api_args' => 'OnFilterPluginsApiArgs',
        'plugins_api_result' => 'OnFilterPluginsApiResult',
        'plugins_update_check_locales' => 'OnFilterPluginsUpdateCheckLocales',
        'plugins_url' => 'OnFilterPluginsUrl',
        'plupload_default_params' => 'OnFilterPluploadDefaultParams',
        'plupload_default_settings' => 'OnFilterPluploadDefaultSettings',
        'plupload_init' => 'OnFilterPluploadInit',
        'populate_network_meta' => 'OnFilterPopulateNetworkMeta',
        'post_class' => 'OnFilterPostClass',
        'post_comments_feed_link' => 'OnFilterPostCommentsFeedLink',
        'post_comments_feed_link_html' => 'OnFilterPostCommentsFeedLinkHtml',
        'post_comments_link' => 'OnFilterPostCommentsLink',
        'post_date_column_time' => 'OnFilterPostDateColumnTime',
        'post_format_rewrite_base' => 'OnFilterPostFormatRewriteBase',
        'post_gallery' => 'OnFilterPostGallery',
        'post_limits' => 'OnFilterPostLimits',
        'post_limits_request' => 'OnFilterPostLimitsRequest',
        'post_link' => 'OnFilterPostLink',
        'post_link_category' => 'OnFilterPostLinkCategory',
        'post_mime_types' => 'OnFilterPostMimeTypes',
        'post_password_expires' => 'OnFilterPostPasswordExpires',
        'post_playlist' => 'OnFilterPostPlaylist',
        'post_rewrite_rules' => 'OnFilterPostRewriteRules',
        'post_row_actions' => 'OnFilterPostRowActions',
        'post_thumbnail_html' => 'OnFilterPostThumbnailHtml',
        'post_thumbnail_size' => 'OnFilterPostThumbnailSize',
        'post_type_archive_feed_link' => 'OnFilterPostTypeArchiveFeedLink',
        'post_type_archive_link' => 'OnFilterPostTypeArchiveLink',
        'post_type_archive_title' => 'OnFilterPostTypeArchiveTitle',
        'post_type_link' => 'OnFilterPostTypeLink',
        'post_types_to_delete_with_user' => 'OnFilterPostTypesToDeleteWithUser',
        'post_updated_messages' => 'OnFilterPostUpdatedMessages',
        'postmeta_form_limit' => 'OnFilterPostmetaFormLimit',
        'posts_clauses' => 'OnFilterPostsClauses',
        'posts_clauses_request' => 'OnFilterPostsClausesRequest',
        'posts_distinct' => 'OnFilterPostsDistinct',
        'posts_distinct_request' => 'OnFilterPostsDistinctRequest',
        'posts_fields' => 'OnFilterPostsFields',
        'posts_fields_request' => 'OnFilterPostsFieldsRequest',
        'posts_groupby' => 'OnFilterPostsGroupby',
        'posts_groupby_request' => 'OnFilterPostsGroupbyRequest',
        'posts_join' => 'OnFilterPostsJoin',
        'posts_join_paged' => 'OnFilterPostsJoinPaged',
        'posts_join_request' => 'OnFilterPostsJoinRequest',
        'posts_orderby' => 'OnFilterPostsOrderby',
        'posts_orderby_request' => 'OnFilterPostsOrderbyRequest',
        'posts_request' => 'OnFilterPostsRequest',
        'posts_request_ids' => 'OnFilterPostsRequestIds',
        'posts_results' => 'OnFilterPostsResults',
        'posts_search' => 'OnFilterPostsSearch',
        'posts_search_orderby' => 'OnFilterPostsSearchOrderby',
        'posts_where' => 'OnFilterPostsWhere',
        'posts_where_paged' => 'OnFilterPostsWherePaged',
        'posts_where_request' => 'OnFilterPostsWhereRequest',
        'pre_category_nicename' => 'OnFilterPreCategoryNicename',
        'pre_comment_approved' => 'OnFilterPreCommentApproved',
        'pre_comment_author_email' => 'OnFilterPreCommentAuthorEmail',
        'pre_comment_author_name' => 'OnFilterPreCommentAuthorName',
        'pre_comment_author_url' => 'OnFilterPreCommentAuthorUrl',
        'pre_comment_content' => 'OnFilterPreCommentContent',
        'pre_comment_user_agent' => 'OnFilterPreCommentUserAgent',
        'pre_comment_user_ip' => 'OnFilterPreCommentUserIp',
        'pre_ent2ncr' => 'OnFilterPreEnt2ncr',
        'pre_get_col_charset' => 'OnFilterPreGetColCharset',
        'pre_get_network_by_path' => 'OnFilterPreGetNetworkByPath',
        'pre_get_shortlink' => 'OnFilterPreGetShortlink',
        'pre_get_site_by_path' => 'OnFilterPreGetSiteByPath',
        'pre_get_space_used' => 'OnFilterPreGetSpaceUsed',
        'pre_get_table_charset' => 'OnFilterPreGetTableCharset',
        'pre_http_request' => 'OnFilterPreHttpRequest',
        'pre_http_send_through_proxy' => 'OnFilterPreHttpSendThroughProxy',
        'pre_insert_term' => 'OnFilterPreInsertTerm',
        'pre_kses' => 'OnFilterPreKses',
        'pre_option_enable_xmlrpc' => 'OnFilterPreOptionEnableXmlrpc',
        'pre_post_link' => 'OnFilterPrePostLink',
        'pre_remote_source' => 'OnFilterPreRemoteSource',
        'pre_update_option' => 'OnFilterPreUpdateOption',
        'pre_upload_error' => 'OnFilterPreUploadError',
        'pre_user_description' => 'OnFilterPreUserDescription',
        'pre_user_display_name' => 'OnFilterPreUserDisplayName',
        'pre_user_email' => 'OnFilterPreUserEmail',
        'pre_user_first_name' => 'OnFilterPreUserFirstName',
        'pre_user_id' => 'OnFilterPreUserId',
        'pre_user_last_name' => 'OnFilterPreUserLastName',
        'pre_user_login' => 'OnFilterPreUserLogin',
        'pre_user_nicename' => 'OnFilterPreUserNicename',
        'pre_user_nickname' => 'OnFilterPreUserNickname',
        'pre_user_url' => 'OnFilterPreUserUrl',
        'pre_wp_nav_menu' => 'OnFilterPreWPNavMenu',
        'prepend_attachment' => 'OnFilterPrependAttachment',
        'preprocess_comment' => 'OnFilterPreprocessComment',
        'preview_post_link' => 'OnFilterPreviewPostLink',
        'previous_comments_link_attributes' => 'OnFilterPreviousCommentsLinkAttributes',
        'previous_posts_link_attributes' => 'OnFilterPreviousPostsLinkAttributes',
        'print_admin_styles' => 'OnFilterPrintAdminStyles',
        'print_footer_scripts' => 'OnFilterPrintFooterScripts',
        'print_head_scripts' => 'OnFilterPrintHeadScripts',
        'print_late_styles' => 'OnFilterPrintLateStyles',
        'print_scripts_array' => 'OnFilterPrintScriptsArray',
        'print_styles_array' => 'OnFilterPrintStylesArray',
        'privacy_on_link_text' => 'OnFilterPrivacyOnLinkText',
        'privacy_on_link_title' => 'OnFilterPrivacyOnLinkTitle',
        'private_title_format' => 'OnFilterPrivateTitleFormat',
        'process_text_diff_html' => 'OnFilterProcessTextDiffHtml',
        'protected_title_format' => 'OnFilterProtectedTitleFormat',
        'pub_priv_sql_capability' => 'OnFilterPubPrivSqlCapability',
        'query' => 'OnFilterQuery',
        'query_string' => 'OnFilterQueryString',
        'query_vars' => 'OnFilterQueryVars',
        'quick_edit_dropdown_pages_args' => 'OnFilterQuickEditDropdownPagesArgs',
        'quicktags_settings' => 'OnFilterQuicktagsSettings',
        'random_password' => 'OnFilterRandomPassword',
        'redirect_canonical' => 'OnFilterRedirectCanonical',
        'redirect_network_admin_request' => 'OnFilterRedirectNetworkAdminRequest',
        'redirect_post_location' => 'OnFilterRedirectPostLocation',
        'redirect_user_admin_request' => 'OnFilterRedirectUserAdminRequest',
        'register' => 'OnFilterRegister',
        'register_url' => 'OnFilterRegisterUrl',
        'registration_errors' => 'OnFilterRegistrationErrors',
        'registration_redirect' => 'OnFilterRegistrationRedirect',
        'request' => 'OnFilterRequest',
        'request_filesystem_credentials' => 'OnFilterRequestFilesystemCredentials',
        'retrieve_password_message' => 'OnFilterRetrievePasswordMessage',
        'retrieve_password_title' => 'OnFilterRetrievePasswordTitle',
        'revision_text_diff_options' => 'OnFilterRevisionTextDiffOptions',
        'rewrite_rules' => 'OnFilterRewriteRules',
        'rewrite_rules_array' => 'OnFilterRewriteRulesArray',
        'richedit_pre' => 'OnFilterRicheditPre',
        'robots_txt' => 'OnFilterRobotsTxt',
        'role_has_cap' => 'OnFilterRoleHasCap',
        'root_rewrite_rules' => 'OnFilterRootRewriteRules',
        'rss_enclosure' => 'OnFilterRssEnclosure',
        'rss_update_frequency' => 'OnFilterRssUpdateFrequency',
        'rss_update_period' => 'OnFilterRssUpdatePeriod',
        'run_wptexturize' => 'OnFilterRunWptexturize',
        'safe_style_css' => 'OnFilterSafeStyleCss',
        'salt' => 'OnFilterSalt',
        'sanitize_email' => 'OnFilterSanitizeEmail',
        'sanitize_file_name' => 'OnFilterSanitizeFileName',
        'sanitize_file_name_chars' => 'OnFilterSanitizeFileNameChars',
        'sanitize_html_class' => 'OnFilterSanitizeHtmlClass',
        'sanitize_key' => 'OnFilterSanitizeKey',
        'sanitize_mime_type' => 'OnFilterSanitizeMimeType',
        'sanitize_text_field' => 'OnFilterSanitizeTextField',
        'sanitize_trackback_urls' => 'OnFilterSanitizeTrackbackUrls',
        'sanitize_user' => 'OnFilterSanitizeUser',
        'schedule_event' => 'OnFilterScheduleEvent',
        'screen_layout_columns' => 'OnFilterScreenLayoutColumns',
        'screen_options_show_screen' => 'OnFilterScreenOptionsShowScreen',
        'screen_settings' => 'OnFilterScreenSettings',
        'script_loader_src' => 'OnFilterScriptLoaderSrc',
        'script_loader_tag' => 'OnFilterScriptLoaderTag',
        'search_feed_link' => 'OnFilterSearchFeedLink',
        'search_form_format' => 'OnFilterSearchFormFormat',
        'search_link' => 'OnFilterSearchLink',
        'search_rewrite_rules' => 'OnFilterSearchRewriteRules',
        'secure_auth_cookie' => 'OnFilterSecureAuthCookie',
        'secure_auth_redirect' => 'OnFilterSecureAuthRedirect',
        'secure_logged_in_cookie' => 'OnFilterSecureLoggedInCookie',
        'secure_signon_cookie' => 'OnFilterSecureSignonCookie',
        'self_link' => 'OnFilterSelfLink',
        'send_core_update_notification_email' => 'OnFilterSendCoreUpdateNotificationEmail',
        'session_token_manager' => 'OnFilterSessionTokenManager',
        'set-screen-option' => 'OnFilterSetScreenOption',
        'set_url_scheme' => 'OnFilterSetUrlScheme',
        'shake_error_codes' => 'OnFilterShakeErrorCodes',
        'shortcut_link' => 'OnFilterShortcutLink',
        'show_admin_bar' => 'OnFilterShowAdminBar',
        'show_advanced_plugins' => 'OnFilterShowAdvancedPlugins',
        'show_network_site_users_add_existing_form' => 'OnFilterShowNetworkSiteUsersAddExistingForm',
        'show_network_site_users_add_new_form' => 'OnFilterShowNetworkSiteUsersAddNewForm',
        'show_password_fields' => 'OnFilterShowPasswordFields',
        'show_post_locked_dialog' => 'OnFilterShowPostLockedDialog',
        'show_recent_comments_widget_style' => 'OnFilterShowRecentCommentsWidgetStyle',
        'sidebars_widgets' => 'OnFilterSidebarsWidgets',
        'signup_another_blog_init' => 'OnFilterSignupAnotherBlogInit',
        'signup_blog_init' => 'OnFilterSignupBlogInit',
        'signup_create_blog_meta' => 'OnFilterSignupCreateBlogMeta',
        'signup_user_init' => 'OnFilterSignupUserInit',
        'single_cat_title' => 'OnFilterSingleCatTitle',
        'single_post_title' => 'OnFilterSinglePostTitle',
        'single_tag_title' => 'OnFilterSingleTagTitle',
        'single_term_title' => 'OnFilterSingleTermTitle',
        'site_by_path_segments_count' => 'OnFilterSiteByPathSegmentsCount',
        'site_url' => 'OnFilterSiteUrl',
        'smilies_src' => 'OnFilterSmiliesSrc',
        'split_the_query' => 'OnFilterSplitTheQuery',
        'status_header' => 'OnFilterStatusHeader',
        'style_loader_src' => 'OnFilterStyleLoaderSrc',
        'style_loader_tag' => 'OnFilterStyleLoaderTag',
        'stylesheet' => 'OnFilterStylesheet',
        'stylesheet_directory' => 'OnFilterStylesheetDirectory',
        'stylesheet_directory_uri' => 'OnFilterStylesheetDirectoryUri',
        'stylesheet_uri' => 'OnFilterStylesheetUri',
        'subdirectory_reserved_names' => 'OnFilterSubdirectoryReservedNames',
        'tables_to_repair' => 'OnFilterTablesToRepair',
        'tag_cloud_sort' => 'OnFilterTagCloudSort',
        'tag_escape' => 'OnFilterTagEscape',
        'tag_feed_link' => 'OnFilterTagFeedLink',
        'tag_link' => 'OnFilterTagLink',
        'tag_rewrite_rules' => 'OnFilterTagRewriteRules',
        'tag_row_actions' => 'OnFilterTagRowActions',
        'tagsperpage' => 'OnFilterTagsperpage',
        'taxonomy_feed_link' => 'OnFilterTaxonomyFeedLink',
        'taxonomy_parent_dropdown_args' => 'OnFilterTaxonomyParentDropdownArgs',
        'teeny_mce_before_init' => 'OnFilterTeenyMceBeforeInit',
        'teeny_mce_buttons' => 'OnFilterTeenyMceButtons',
        'teeny_mce_plugins' => 'OnFilterTeenyMcePlugins',
        'template' => 'OnFilterTemplate',
        'template_directory' => 'OnFilterTemplateDirectory',
        'template_directory_uri' => 'OnFilterTemplateDirectoryUri',
        'template_include' => 'OnFilterTemplateInclude',
        'term_id_filter' => 'OnFilterTermIdFilter',
        'term_link' => 'OnFilterTermLink',
        'term_name' => 'OnFilterTermName',
        'term_search_min_chars' => 'OnFilterTermSearchMinChars',
        'term_updated_messages' => 'OnFilterTermUpdatedMessages',
        'terms_clauses' => 'OnFilterTermsClauses',
        'terms_to_edit' => 'OnFilterTermsToEdit',
        'the_author' => 'OnFilterTheAuthor',
        'the_author_posts_link' => 'OnFilterTheAuthorPostsLink',
        'the_category' => 'OnFilterTheCategory',
        'the_category_rss' => 'OnFilterTheCategoryRss',
        'the_comments' => 'OnFilterTheComments',
        'the_content' => 'OnFilterTheContent',
        'the_content_export' => 'OnFilterTheContentExport',
        'the_content_feed' => 'OnFilterTheContentFeed',
        'the_content_more_link' => 'OnFilterTheContentMoreLink',
        'the_content_rss' => 'OnFilterTheContentRss',
        'the_date' => 'OnFilterTheDate',
        'the_editor' => 'OnFilterTheEditor',
        'the_editor_content' => 'OnFilterTheEditorContent',
        'the_excerpt' => 'OnFilterTheExcerpt',
        'the_excerpt_export' => 'OnFilterTheExcerptExport',
        'the_excerpt_rss' => 'OnFilterTheExcerptRss',
        'the_feed_link' => 'OnFilterTheFeedLink',
        'the_generator' => 'OnFilterTheGenerator',
        'the_meta_key' => 'OnFilterTheMetaKey',
        'the_modified_author' => 'OnFilterTheModifiedAuthor',
        'the_modified_date' => 'OnFilterTheModifiedDate',
        'the_modified_time' => 'OnFilterTheModifiedTime',
        'the_password_form' => 'OnFilterThePasswordForm',
        'the_permalink' => 'OnFilterThePermalink',
        'the_permalink_rss' => 'OnFilterThePermalinkRss',
        'the_posts' => 'OnFilterThePosts',
        'the_preview' => 'OnFilterThePreview',
        'the_search_query' => 'OnFilterTheSearchQuery',
        'the_shortlink' => 'OnFilterTheShortlink',
        'the_tags' => 'OnFilterTheTags',
        'the_terms' => 'OnFilterTheTerms',
        'the_time' => 'OnFilterTheTime',
        'the_title' => 'OnFilterTheTitle',
        'the_title_rss' => 'OnFilterTheTitleRss',
        'the_weekday' => 'OnFilterTheWeekday',
        'the_weekday_date' => 'OnFilterTheWeekdayDate',
        'theme_action_links' => 'OnFilterThemeActionLinks',
        'theme_install_actions' => 'OnFilterThemeInstallActions',
        'theme_locale' => 'OnFilterThemeLocale',
        'theme_page_templates' => 'OnFilterThemePageTemplates',
        'theme_root' => 'OnFilterThemeRoot',
        'theme_root_uri' => 'OnFilterThemeRootUri',
        'theme_row_meta' => 'OnFilterThemeRowMeta',
        'themes_api' => 'OnFilterThemesApi',
        'themes_api_args' => 'OnFilterThemesApiArgs',
        'themes_api_result' => 'OnFilterThemesApiResult',
        'themes_update_check_locales' => 'OnFilterThemesUpdateCheckLocales',
        'thread_comments_depth_max' => 'OnFilterThreadCommentsDepthMax',
        'time_formats' => 'OnFilterTimeFormats',
        'tiny_mce_before_init' => 'OnFilterTinyMceBeforeInit',
        'tiny_mce_plugins' => 'OnFilterTinyMcePlugins',
        'trackback_url' => 'OnFilterTrackbackUrl',
        'translations_api' => 'OnFilterTranslationsApi',
        'translations_api_result' => 'OnFilterTranslationsApiResult',
        'twentyfourteen_attachment_size' => 'OnFilterTwentyfourteenAttachmentSize',
        'twentyfourteen_custom_background_args' => 'OnFilterTwentyfourteenCustomBackgroundArgs',
        'twentyfourteen_custom_header_args' => 'OnFilterTwentyfourteenCustomHeaderArgs',
        'twentyfourteen_get_featured_posts' => 'OnFilterTwentyfourteenGetFeaturedPosts',
        'twentythirteen_attachment_size' => 'OnFilterTwentythirteenAttachmentSize',
        'twentythirteen_author_bio_avatar_size' => 'OnFilterTwentythirteenAuthorBioAvatarSize',
        'twentytwelve_attachment_size' => 'OnFilterTwentytwelveAttachmentSize',
        'twentytwelve_author_bio_avatar_size' => 'OnFilterTwentytwelveAuthorBioAvatarSize',
        'twentytwelve_status_avatar' => 'OnFilterTwentytwelveStatusAvatar',
        'type_url_form_media' => 'OnFilterTypeUrlFormMedia',
        'unzip_file_use_ziparchive' => 'OnFilterUnzipFileUseZiparchive',
        'update_attached_file' => 'OnFilterUpdateAttachedFile',
        'update_bulk_plugins_complete_actions' => 'OnFilterUpdateBulkPluginsCompleteActions',
        'update_bulk_theme_complete_actions' => 'OnFilterUpdateBulkThemeCompleteActions',
        'update_feedback' => 'OnFilterUpdateFeedback',
        'update_footer' => 'OnFilterUpdateFooter',
        'update_plugin_complete_actions' => 'OnFilterUpdatePluginCompleteActions',
        'update_theme_complete_actions' => 'OnFilterUpdateThemeCompleteActions',
        'update_translations_complete_actions' => 'OnFilterUpdateTranslationsCompleteActions',
        'update_welcome_email' => 'OnFilterUpdateWelcomeEmail',
        'update_welcome_subject' => 'OnFilterUpdateWelcomeSubject',
        'update_welcome_user_email' => 'OnFilterUpdateWelcomeUserEmail',
        'update_welcome_user_subject' => 'OnFilterUpdateWelcomeUserSubject',
        'upgrader_clear_destination' => 'OnFilterUpgraderClearDestination',
        'upgrader_post_install' => 'OnFilterUpgraderPostInstall',
        'upgrader_pre_download' => 'OnFilterUpgraderPreDownload',
        'upgrader_pre_install' => 'OnFilterUpgraderPreInstall',
        'upgrader_source_selection' => 'OnFilterUpgraderSourceSelection',
        'upload_dir' => 'OnFilterUploadDir',
        'upload_mimes' => 'OnFilterUploadMimes',
        'upload_per_page' => 'OnFilterUploadPerPage',
        'upload_post_params' => 'OnFilterUploadPostParams',
        'upload_size_limit' => 'OnFilterUploadSizeLimit',
        'url_to_postid' => 'OnFilterUrlToPostid',
        'use_curl_transport' => 'OnFilterUseCurlTransport',
        'use_default_gallery_style' => 'OnFilterUseDefaultGalleryStyle',
        'use_google_chrome_frame' => 'OnFilterUseGoogleChromeFrame',
        'use_streams_transport' => 'OnFilterUseStreamsTransport',
        'user_admin_url' => 'OnFilterUserAdminUrl',
        'user_can_richedit' => 'OnFilterUserCanRichedit',
        'user_contactmethods' => 'OnFilterUserContactmethods',
        'user_dashboard_url' => 'OnFilterUserDashboardUrl',
        'user_has_cap' => 'OnFilterUserHasCap',
        'user_registration_email' => 'OnFilterUserRegistrationEmail',
        'user_row_actions' => 'OnFilterUserRowActions',
        'user_search_columns' => 'OnFilterUserSearchColumns',
        'user_trailingslashit' => 'OnFilterUserTrailingslashit',
        'validate_current_theme' => 'OnFilterValidateCurrentTheme',
        'validate_username' => 'OnFilterValidateUsername',
        'wp_admin_bar_class' => 'OnFilterWPAdminBarClass',
        'wp_admin_css' => 'OnFilterWPAdminCss',
        'wp_admin_css_uri' => 'OnFilterWPAdminCssUri',
        'wp_audio_embed_handler' => 'OnFilterWPAudioEmbedHandler',
        'wp_audio_extensions' => 'OnFilterWPAudioExtensions',
        'wp_audio_shortcode' => 'OnFilterWPAudioShortcode',
        'wp_audio_shortcode_class' => 'OnFilterWPAudioShortcodeClass',
        'wp_audio_shortcode_library' => 'OnFilterWPAudioShortcodeLibrary',
        'wp_audio_shortcode_override' => 'OnFilterWPAudioShortcodeOverride',
        'wp_auth_check_interval' => 'OnFilterWPAuthCheckInterval',
        'wp_auth_check_load' => 'OnFilterWPAuthCheckLoad',
        'wp_auth_check_same_domain' => 'OnFilterWPAuthCheckSameDomain',
        'wp_authenticate_user' => 'OnFilterWPAuthenticateUser',
        'wp_cache_themes_persistently' => 'OnFilterWPCacheThemesPersistently',
        'wp_check_filetype_and_ext' => 'OnFilterWPCheckFiletypeAndExt',
        'wp_check_post_lock_window' => 'OnFilterWPCheckPostLockWindow',
        'wp_checkdate' => 'OnFilterWPCheckdate',
        'wp_comment_reply' => 'OnFilterWPCommentReply',
        'wp_count_attachments' => 'OnFilterWPCountAttachments',
        'wp_count_comments' => 'OnFilterWPCountComments',
        'wp_count_posts' => 'OnFilterWPCountPosts',
        'wp_create_file_in_uploads' => 'OnFilterWPCreateFileInUploads',
        'wp_create_thumbnail' => 'OnFilterWPCreateThumbnail',
        'wp_dashboard_widgets' => 'OnFilterWPDashboardWidgets',
        'wp_default_editor' => 'OnFilterWPDefaultEditor',
        'wp_delete_file' => 'OnFilterWPDeleteFile',
        'wp_die_ajax_handler' => 'OnFilterWPDieAjaxHandler',
        'wp_die_handler' => 'OnFilterWPDieHandler',
        'wp_die_xmlrpc_handler' => 'OnFilterWPDieXmlrpcHandler',
        'wp_dropdown_cats' => 'OnFilterWPDropdownCats',
        'wp_dropdown_pages' => 'OnFilterWPDropdownPages',
        'wp_dropdown_users' => 'OnFilterWPDropdownUsers',
        'wp_edit_nav_menu_walker' => 'OnFilterWPEditNavMenuWalker',
        'wp_editor_expand' => 'OnFilterWPEditorExpand',
        'wp_editor_set_quality' => 'OnFilterWPEditorSetQuality',
        'wp_editor_settings' => 'OnFilterWPEditorSettings',
        'wp_embed_handler_audio' => 'OnFilterWPEmbedHandlerAudio',
        'wp_embed_handler_video' => 'OnFilterWPEmbedHandlerVideo',
        'wp_embed_handler_youtube' => 'OnFilterWPEmbedHandlerYoutube',
        'wp_feed_cache_transient_lifetime' => 'OnFilterWPFeedCacheTransientLifetime',
        'wp_fullscreen_buttons' => 'OnFilterWPFullscreenButtons',
        'wp_generate_attachment_metadata' => 'OnFilterWPGenerateAttachmentMetadata',
        'wp_generate_tag_cloud' => 'OnFilterWPGenerateTagCloud',
        'wp_generator_type' => 'OnFilterWPGeneratorType',
        'wp_get_attachment_id3_keys' => 'OnFilterWPGetAttachmentId3Keys',
        'wp_get_attachment_image_attributes' => 'OnFilterWPGetAttachmentImageAttributes',
        'wp_get_attachment_link' => 'OnFilterWPGetAttachmentLink',
        'wp_get_attachment_metadata' => 'OnFilterWPGetAttachmentMetadata',
        'wp_get_attachment_thumb_file' => 'OnFilterWPGetAttachmentThumbFile',
        'wp_get_attachment_thumb_url' => 'OnFilterWPGetAttachmentThumbUrl',
        'wp_get_attachment_url' => 'OnFilterWPGetAttachmentUrl',
        'wp_get_current_commenter' => 'OnFilterWPGetCurrentCommenter',
        'wp_get_nav_menu_items' => 'OnFilterWPGetNavMenuItems',
        'wp_get_nav_menus' => 'OnFilterWPGetNavMenus',
        'wp_get_object_terms' => 'OnFilterWPGetObjectTerms',
        'wp_get_revision_ui_diff' => 'OnFilterWPGetRevisionUiDiff',
        'wp_get_update_data' => 'OnFilterWPGetUpdateData',
        'wp_handle_upload' => 'OnFilterWPHandleUpload',
        'wp_handle_upload_prefilter' => 'OnFilterWPHandleUploadPrefilter',
        'wp_header_image_attachment_metadata' => 'OnFilterWPHeaderImageAttachmentMetadata',
        'wp_headers' => 'OnFilterWPHeaders',
        'wp_http_accept_encoding' => 'OnFilterWPHttpAcceptEncoding',
        'wp_http_cookie_value' => 'OnFilterWPHttpCookieValue',
        'wp_image_editor_before_change' => 'OnFilterWPImageEditorBeforeChange',
        'wp_image_editors' => 'OnFilterWPImageEditors',
        'wp_insert_attachment_data' => 'OnFilterWPInsertAttachmentData',
        'wp_insert_post_data' => 'OnFilterWPInsertPostData',
        'wp_insert_post_empty_content' => 'OnFilterWPInsertPostEmptyContent',
        'wp_insert_post_parent' => 'OnFilterWPInsertPostParent',
        'wp_is_large_network' => 'OnFilterWPIsLargeNetwork',
        'wp_kses_allowed_html' => 'OnFilterWPKsesAllowedHtml',
        'wp_link_pages' => 'OnFilterWPLinkPages',
        'wp_link_pages_args' => 'OnFilterWPLinkPagesArgs',
        'wp_link_pages_link' => 'OnFilterWPLinkPagesLink',
        'wp_link_query' => 'OnFilterWPLinkQuery',
        'wp_link_query_args' => 'OnFilterWPLinkQueryArgs',
        'wp_list_bookmarks' => 'OnFilterWPListBookmarks',
        'wp_list_categories' => 'OnFilterWPListCategories',
        'wp_list_comments_args' => 'OnFilterWPListCommentsArgs',
        'wp_list_pages' => 'OnFilterWPListPages',
        'wp_list_pages_excludes' => 'OnFilterWPListPagesExcludes',
        'wp_login_errors' => 'OnFilterWPLoginErrors',
        'wp_mail' => 'OnFilterWPMail',
        'wp_mail_charset' => 'OnFilterWPMailCharset',
        'wp_mail_content_type' => 'OnFilterWPMailContentType',
        'wp_mail_from' => 'OnFilterWPMailFrom',
        'wp_mail_from_name' => 'OnFilterWPMailFromName',
        'wp_mail_original_content' => 'OnFilterWPMailOriginalContent',
        'wp_mce_translation' => 'OnFilterWPMceTranslation',
        'wp_mediaelement_fallback' => 'OnFilterWPMediaelementFallback',
        'wp_mime_type_icon' => 'OnFilterWPMimeTypeIcon',
        'wp_nav_locations_listed_per_menu' => 'OnFilterWPNavLocationsListedPerMenu',
        'wp_nav_menu' => 'OnFilterWPNavMenu',
        'wp_nav_menu_args' => 'OnFilterWPNavMenuArgs',
        'wp_nav_menu_container_allowedtags' => 'OnFilterWPNavMenuContainerAllowedtags',
        'wp_nav_menu_items' => 'OnFilterWPNavMenuItems',
        'wp_nav_menu_objects' => 'OnFilterWPNavMenuObjects',
        'wp_network_dashboard_widgets' => 'OnFilterWPNetworkDashboardWidgets',
        'wp_page_menu' => 'OnFilterWPPageMenu',
        'wp_page_menu_args' => 'OnFilterWPPageMenuArgs',
        'wp_parse_str' => 'OnFilterWPParseStr',
        'wp_prepare_attachment_for_js' => 'OnFilterWPPrepareAttachmentForJs',
        'wp_prepare_themes_for_js' => 'OnFilterWPPrepareThemesForJs',
        'wp_read_image_metadata' => 'OnFilterWPReadImageMetadata',
        'wp_read_image_metadata_types' => 'OnFilterWPReadImageMetadataTypes',
        'wp_redirect' => 'OnFilterWPRedirect',
        'wp_redirect_status' => 'OnFilterWPRedirectStatus',
        'wp_revisions_to_keep' => 'OnFilterWPRevisionsToKeep',
        'wp_save_image_editor_file' => 'OnFilterWPSaveImageEditorFile',
        'wp_save_image_file' => 'OnFilterWPSaveImageFile',
        'wp_save_post_revision_check_for_changes' => 'OnFilterWPSavePostRevisionCheckForChanges',
        'wp_save_post_revision_post_has_changed' => 'OnFilterWPSavePostRevisionPostHasChanged',
        'wp_search_stopwords' => 'OnFilterWPSearchStopwords',
        'wp_setup_nav_menu_item' => 'OnFilterWPSetupNavMenuItem',
        'wp_signup_location' => 'OnFilterWPSignupLocation',
        'wp_spaces_regexp' => 'OnFilterWPSpacesRegexp',
        'wp_sprintf' => 'OnFilterWPSprintf',
        'wp_sprintf_l' => 'OnFilterWPSprintfL',
        'wp_tag_cloud' => 'OnFilterWPTagCloud',
        'wp_terms_checklist_args' => 'OnFilterWPTermsChecklistArgs',
        'wp_title' => 'OnFilterWPTitle',
        'wp_title_parts' => 'OnFilterWPTitleParts',
        'wp_title_rss' => 'OnFilterWPTitleRss',
        'wp_trim_excerpt' => 'OnFilterWPTrimExcerpt',
        'wp_trim_words' => 'OnFilterWPTrimWords',
        'wp_unique_post_slug' => 'OnFilterWPUniquePostSlug',
        'wp_unique_post_slug_is_bad_attachment_slug' => 'OnFilterWPUniquePostSlugIsBadAttachmentSlug',
        'wp_unique_post_slug_is_bad_flat_slug' => 'OnFilterWPUniquePostSlugIsBadFlatSlug',
        'wp_unique_post_slug_is_bad_hierarchical_slug' => 'OnFilterWPUniquePostSlugIsBadHierarchicalSlug',
        'wp_update_attachment_metadata' => 'OnFilterWPUpdateAttachmentMetadata',
        'wp_update_term_parent' => 'OnFilterWPUpdateTermParent',
        'wp_upload_bits' => 'OnFilterWPUploadBits',
        'wp_user_dashboard_widgets' => 'OnFilterWPUserDashboardWidgets',
        'wp_video_embed_handler' => 'OnFilterWPVideoEmbedHandler',
        'wp_video_extensions' => 'OnFilterWPVideoExtensions',
        'wp_video_shortcode' => 'OnFilterWPVideoShortcode',
        'wp_video_shortcode_class' => 'OnFilterWPVideoShortcodeClass',
        'wp_video_shortcode_library' => 'OnFilterWPVideoShortcodeLibrary',
        'wp_video_shortcode_override' => 'OnFilterWPVideoShortcodeOverride',
        'wp_xmlrpc_server_class' => 'OnFilterWPXmlrpcServerClass',
        'walker_nav_menu_start_el' => 'OnFilterWalkerNavMenuStartEl',
        'whitelist_options' => 'OnFilterWhitelistOptions',
        'widget_archives_args' => 'OnFilterWidgetArchivesArgs',
        'widget_archives_dropdown_args' => 'OnFilterWidgetArchivesDropdownArgs',
        'widget_categories_args' => 'OnFilterWidgetCategoriesArgs',
        'widget_categories_dropdown_args' => 'OnFilterWidgetCategoriesDropdownArgs',
        'widget_comments_args' => 'OnFilterWidgetCommentsArgs',
        'widget_customizer_setting_args' => 'OnFilterWidgetCustomizerSettingArgs',
        'widget_display_callback' => 'OnFilterWidgetDisplayCallback',
        'widget_form_callback' => 'OnFilterWidgetFormCallback',
        'widget_links_args' => 'OnFilterWidgetLinksArgs',
        'widget_meta_poweredby' => 'OnFilterWidgetMetaPoweredby',
        'widget_pages_args' => 'OnFilterWidgetPagesArgs',
        'widget_posts_args' => 'OnFilterWidgetPostsArgs',
        'widget_tag_cloud_args' => 'OnFilterWidgetTagCloudArgs',
        'widget_text' => 'OnFilterWidgetText',
        'widget_title' => 'OnFilterWidgetTitle',
        'widget_update_callback' => 'OnFilterWidgetUpdateCallback',
        'wpmu_active_signup' => 'OnFilterWpmuActiveSignup',
        'wpmu_blogs_columns' => 'OnFilterWpmuBlogsColumns',
        'wpmu_delete_blog_upload_dir' => 'OnFilterWpmuDeleteBlogUploadDir',
        'wpmu_drop_tables' => 'OnFilterWpmuDropTables',
        'wpmu_signup_blog_notification' => 'OnFilterWpmuSignupBlogNotification',
        'wpmu_signup_blog_notification_email' => 'OnFilterWpmuSignupBlogNotificationEmail',
        'wpmu_signup_blog_notification_subject' => 'OnFilterWpmuSignupBlogNotificationSubject',
        'wpmu_signup_user_notification' => 'OnFilterWpmuSignupUserNotification',
        'wpmu_signup_user_notification_email' => 'OnFilterWpmuSignupUserNotificationEmail',
        'wpmu_signup_user_notification_subject' => 'OnFilterWpmuSignupUserNotificationSubject',
        'wpmu_users_columns' => 'OnFilterWpmuUsersColumns',
        'wpmu_validate_blog_signup' => 'OnFilterWpmuValidateBlogSignup',
        'wpmu_validate_user_signup' => 'OnFilterWpmuValidateUserSignup',
        'wpmu_welcome_notification' => 'OnFilterWpmuWelcomeNotification',
        'wpmu_welcome_user_notification' => 'OnFilterWpmuWelcomeUserNotification',
        'wxr_export_skip_commentmeta' => 'OnFilterWxrExportSkipCommentmeta',
        'wxr_export_skip_postmeta' => 'OnFilterWxrExportSkipPostmeta',
        'xmlrpc_allow_anonymous_comments' => 'OnFilterXmlrpcAllowAnonymousComments',
        'xmlrpc_blog_options' => 'OnFilterXmlrpcBlogOptions',
        'xmlrpc_default_post_fields' => 'OnFilterXmlrpcDefaultPostFields',
        'xmlrpc_default_posttype_fields' => 'OnFilterXmlrpcDefaultPosttypeFields',
        'xmlrpc_default_revision_fields' => 'OnFilterXmlrpcDefaultRevisionFields',
        'xmlrpc_default_taxonomy_fields' => 'OnFilterXmlrpcDefaultTaxonomyFields',
        'xmlrpc_default_user_fields' => 'OnFilterXmlrpcDefaultUserFields',
        'xmlrpc_enabled' => 'OnFilterXmlrpcEnabled',
        'xmlrpc_login_error' => 'OnFilterXmlrpcLoginError',
        'xmlrpc_methods' => 'OnFilterXmlrpcMethods',
        'xmlrpc_pingback_error' => 'OnFilterXmlrpcPingbackError',
        'xmlrpc_prepare_comment' => 'OnFilterXmlrpcPrepareComment',
        'xmlrpc_prepare_media_item' => 'OnFilterXmlrpcPrepareMediaItem',
        'xmlrpc_prepare_page' => 'OnFilterXmlrpcPreparePage',
        'xmlrpc_prepare_post' => 'OnFilterXmlrpcPreparePost',
        'xmlrpc_prepare_post_type' => 'OnFilterXmlrpcPreparePostType',
        'xmlrpc_prepare_taxonomy' => 'OnFilterXmlrpcPrepareTaxonomy',
        'xmlrpc_prepare_term' => 'OnFilterXmlrpcPrepareTerm',
        'xmlrpc_prepare_user' => 'OnFilterXmlrpcPrepareUser',
        'xmlrpc_text_filters' => 'OnFilterXmlrpcTextFilters',
        'xmlrpc_wp_insert_post_data' => 'OnFilterXmlrpcWPInsertPostData',
        'year_link' => 'OnFilterYearLink',
        '_get_page_link' => 'OnFilter_GetPageLink',
        '_wp_post_revision_fields' => 'OnFilter_WPPostRevisionFields',
        '_wp_relative_upload_path' => 'OnFilter_WPRelativeUploadPath'
    );

}
